Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/transform/transform.c')
-rw-r--r--source/blender/editors/transform/transform.c18
1 files changed, 10 insertions, 8 deletions
diff --git a/source/blender/editors/transform/transform.c b/source/blender/editors/transform/transform.c
index 57688ca9f3c..7656a8a54c6 100644
--- a/source/blender/editors/transform/transform.c
+++ b/source/blender/editors/transform/transform.c
@@ -203,7 +203,7 @@ static void applySeqSlide(TransInfo *t, const int mval[2]);
static bool transdata_check_local_center(TransInfo *t, short around)
{
- return ((around == V3D_LOCAL) && (
+ return ((around == V3D_AROUND_LOCAL_ORIGINS) && (
(t->flag & (T_OBJECT | T_POSE)) ||
(t->obedit && ELEM(t->obedit->type, OB_MESH, OB_CURVE, OB_MBALL, OB_ARMATURE)) ||
(t->spacetype == SPACE_IPO) ||
@@ -213,7 +213,7 @@ static bool transdata_check_local_center(TransInfo *t, short around)
bool transdata_check_local_islands(TransInfo *t, short around)
{
- return ((around == V3D_LOCAL) && (
+ return ((around == V3D_AROUND_LOCAL_ORIGINS) && (
(t->obedit && ELEM(t->obedit->type, OB_MESH))));
}
@@ -1553,8 +1553,8 @@ bool calculateTransformCenter(bContext *C, int centerMode, float cent3d[3], floa
initTransInfo(C, t, NULL, NULL);
- /* avoid doing connectivity lookups (when V3D_LOCAL is set) */
- t->around = V3D_CENTER;
+ /* avoid doing connectivity lookups (when V3D_AROUND_LOCAL_ORIGINS is set) */
+ t->around = V3D_AROUND_CENTER_BOUNDS;
createTransData(C, t); // make TransData structs from selection
@@ -3018,7 +3018,7 @@ static void Bend(TransInfo *t, const int UNUSED(mval[2]))
/* rotation */
if ((t->flag & T_POINTS) == 0) {
- ElementRotation(t, td, mat, V3D_LOCAL);
+ ElementRotation(t, td, mat, V3D_AROUND_LOCAL_ORIGINS);
}
/* location */
@@ -4345,14 +4345,14 @@ static void applyTranslationValue(TransInfo *t, const float vec[3])
rotation_between_vecs_to_mat3(mat, original_normal, t->tsnap.snapNormal);
- ElementRotation(t, td, mat, V3D_LOCAL);
+ ElementRotation(t, td, mat, V3D_AROUND_LOCAL_ORIGINS);
}
else {
float mat[3][3];
unit_m3(mat);
- ElementRotation(t, td, mat, V3D_LOCAL);
+ ElementRotation(t, td, mat, V3D_AROUND_LOCAL_ORIGINS);
}
}
@@ -8524,7 +8524,9 @@ bool checkUseAxisMatrix(TransInfo *t)
{
/* currently only checks for editmode */
if (t->flag & T_EDIT) {
- if ((t->around == V3D_LOCAL) && (ELEM(t->obedit->type, OB_MESH, OB_CURVE, OB_MBALL, OB_ARMATURE))) {
+ if ((t->around == V3D_AROUND_LOCAL_ORIGINS) &&
+ (ELEM(t->obedit->type, OB_MESH, OB_CURVE, OB_MBALL, OB_ARMATURE)))
+ {
/* not all editmode supports axis-matrix */
return true;
}